@@ -143,7 +143,7 @@ class DispatchServer:
   >>> dataset = tf.data.Dataset.range(10)
   >>> dataset = dataset.apply(tf.data.experimental.service.distribute(
   ...     processing_mode="parallel_epochs", service=dispatcher.target))
-  >>> print(list(dataset.as_numpy_iterator()))
+  >>> [a.item() for a in dataset.as_numpy_iterator()]
   [0, 1, 2, 3, 4, 5, 6, 7, 8, 9]
 
   When starting a dedicated tf.data dispatch process, use join() to block
@@ -334,7 +334,7 @@ class WorkerConfig(
     if protocol is None:
       protocol = _pywrap_utils_exp.TF_DATA_DefaultProtocol()
     if data_transfer_address is None:
-      data_transfer_address = "localhost:%port%"
+      data_transfer_address = "localhost:%dts_port%"
     heartbeat_interval_ms = _get_time_or_placeholder(heartbeat_interval_ms)
     dispatcher_timeout_ms = _get_time_or_placeholder(dispatcher_timeout_ms)
 
@@ -362,7 +362,7 @@ class WorkerServer:
   >>> dataset = tf.data.Dataset.range(10)
   >>> dataset = dataset.apply(tf.data.experimental.service.distribute(
   ...     processing_mode="parallel_epochs", service=dispatcher.target))
-  >>> print(list(dataset.as_numpy_iterator()))
+  >>> [a.item() for a in dataset.as_numpy_iterator()]
   [0, 1, 2, 3, 4, 5, 6, 7, 8, 9]
 
   When starting a dedicated tf.data worker process, use join() to block
